@@ -11,18 +11,15 @@ USE_TASKSMAX=${USE_TASKSMAX:-true}
 # Warning: This variable API is experimental so these variables may be subject
 # to change in the future.
 prefix=${prefix:=/usr}
-initdir=${initdir:=/etc/init.d}
 unitdir_redhat=${unitdir:-/usr/lib/systemd/system}
 unitdir_debian=${unitdir:-/lib/systemd/system}
 defaultsdir_redhat=${defaultsdir:-/etc/sysconfig}
 defaultsdir_debian=${defaultsdir:-/etc/default}
-tmpfilesdir=${tmpfilesdir:=/usr/lib/tmpfiles.d}
 datadir=${datadir:=${prefix}/share}
 real_name=${real_name:=puppetserver}
 projdatadir=${projdatadir:=${datadir}/${real_name}}
 confdir=${confdir:=/etc}
 projconfdir=${projconfdir:=${confdir}/puppetlabs/${real_name}}
-rundir=${rundir:=/var/run/puppetlabs/${real_name}}
 # Application specific bin directory
 bindir=${bindir:=/opt/puppetlabs/server/apps/${real_name}/bin}
 # User facing bin directory, expected to be added to interactive shell PATH
@@ -34,7 +31,6 @@ dest_apps_dir="${DESTDIR}${app_prefix}"
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 system_config_dir=${system_config_dir:=${app_prefix}/config}
-needrestart_confdir=${needrestart_dir:=/etc/needrestart/conf.d}
 
 
 ##################
@@ -74,36 +70,17 @@ function task_service {
     if [ "$OSFAMILY" = "RedHat" ]; then
         unitdir=${unitdir_redhat}
         defaultsdir=${defaultsdir_redhat}
-        if [ $MAJREV -lt 7 ]; then
-            task install_source_rpm_sysv
-        else
-            task install_source_rpm_systemd
-        fi
+        task install_source_rpm_systemd
     elif [ "$OSFAMILY" = "Debian" ]; then
         unitdir=${unitdir_debian}
         defaultsdir=${defaultsdir_debian}
-        sysv_codenames=("squeeze" "wheezy" "lucid" "precise" "trusty")
-        if $(echo ${sysv_codenames[@]} | grep -q $CODENAME) ; then
-            task install_source_deb_sysv
-        else
-            task install_source_deb_systemd
-        fi
+        task install_source_deb_systemd
     else
         echo "Unsupported platform, exiting ..."
         exit 1
     fi
 }
 
-# Source based install for Redhat based + sysv setups
-function task_install_source_rpm_sysv {
-    task preinst_redhat
-    task install_redhat
-    task sysv_init_redhat
-    task logrotate_legacy
-    task postinst_redhat
-    task postinst_permissions
-}
-
 # Source based install for Redhat based + systemd setups
 function task_install_source_rpm_systemd {
     task preinst_redhat
@@ -114,15 +91,6 @@ function task_install_source_rpm_systemd {
     task postinst_permissions
 }
 
-# Source based install for Debian based + sysv setups
-function task_install_source_deb_sysv {
-    task preinst_deb
-    task install_deb
-    task sysv_init_deb
-    task logrotate
-    task postinst_deb
-}
-
 # Source based install for Debian based + systemd setups
 function task_install_source_deb_systemd {
     task preinst_deb
@@ -143,8 +111,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.8.1"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.8.1"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.9.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.9.0"
   fi
 }
 
@@ -154,7 +122,6 @@ function task_install {
     install -d -m 0755 "${dest_apps_dir}"
     install -d -m 0770 "${DESTDIR}${app_data}"
     install -m 0644 puppet-server-release.jar "${dest_apps_dir}"
-    install -m 0755 ext/ezbake-functions.sh "${dest_apps_dir}"
     install -m 0644 ext/ezbake.manifest "${dest_apps_dir}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
 
@@ -186,22 +153,16 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
-    install -m 0755 ext/cli/prune "${dest_apps_dir}/cli/apps/prune"
     install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
-    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
+    install -m 0755 ext/cli/prune "${dest_apps_dir}/cli/apps/prune"
+    install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
     install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
-    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
     install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
-    install -m 0755 ext/cli/dropsonde "${dest_apps_dir}/cli/apps/dropsonde"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
 fi
 
-    install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
     install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/jars"
     install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/yaml"
@@ -230,49 +191,18 @@ function task_defaults_deb {
     install -m 0644 ext/debian/puppetserver.default_file "${DESTDIR}${defaultsdir_debian}/puppetserver"
 }
 
-# Install the sysv and defaults configuration for Redhat.
-function task_sysv_init_redhat {
-    task defaults_redhat
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/redhat/init "${DESTDIR}${initdir}/puppetserver"
-}
-
-# Install the sysv and defaults configuration for SuSE.
-function task_sysv_init_suse {
-    task defaults_redhat
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/redhat/init.suse "${DESTDIR}${initdir}/puppetserver"
-}
-
 # Install the systemd and defaults configuration for Redhat.
 function task_systemd_redhat {
     task defaults_redhat
     install -d -m 0755 "${DESTDIR}${unitdir_redhat}"
     install -m 0644 ext/redhat/puppetserver.service "${DESTDIR}${unitdir_redhat}/puppetserver.service"
-    install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
-    install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
 }
 
-# Install the sysv and defaults configuration for Debian.
-function task_sysv_init_deb {
-    task defaults_deb
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/debian/puppetserver.init_script "${DESTDIR}${initdir}/puppetserver"
-    install -d -m 0755 "${DESTDIR}${rundir}"
-}
-
-# Install the systemd/sysv and defaults configuration for Debian.
+# Install the systemd and defaults configuration for Debian.
 function task_systemd_deb {
-    task sysv_init_deb
+    task defaults_deb
     install -d -m 0755 "${DESTDIR}${unitdir_debian}"
     install -m 0644 ext/debian/puppetserver.service_file "${DESTDIR}${unitdir_debian}/puppetserver.service"
-    if [ "$USE_TASKSMAX" == "false" ]; then
-      sed -i "s/^TasksMax/# Don't set TasksMax since the option doesn't exist\n# TasksMax/" "${DESTDIR}${unitdir_debian}/puppetserver.service"
-    fi
-    install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
-    install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
-    install -d -m 0755 "${DESTDIR}${needrestart_confdir}"
-    install -m 0644 ext/puppetserver.needrestart.conf "${DESTDIR}${needrestart_confdir}/puppetserver.conf"
 }
 
 function task_service_account {
@@ -357,26 +287,18 @@ function task_postinst_permissions {
     chmod 770 $app_data
     chown puppet:puppet $projconfdir
     chmod 750 $projconfdir
-    chown puppet:puppet $rundir
-    chmod 0755 $rundir
     chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/jars
     chmod 700 /opt/puppetlabs/server/data/puppetserver/jars
     chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/yaml
     chmod 700 /opt/puppetlabs/server/data/puppetserver/yaml
 }
 
-# Install logrotate (usually el7, fedora 16 and above)
+# Install logrotate
 function task_logrotate {
     install -d -m 0755 "${DESTDIR}${confdir}/logrotate.d"
     cp -pr ext/puppetserver.logrotate.conf "${DESTDIR}${confdir}/logrotate.d/puppetserver"
 }
 
-# Install legacy logrotate
-function task_logrotate_legacy {
-    install -d -m 0755 "${DESTDIR}${confdir}/logrotate.d"
-    cp -pr ext/puppetserver.logrotate-legacy.conf "${DESTDIR}${confdir}/logrotate.d/puppetserver"
-}
-
 ##################
 # Misc functions #
 ##################
